@@ -42,6 +42,15 @@ our @ISA = qw(Exporter ZoneMinder::Base);
 # will save memory.
 our %EXPORT_TAGS = (
     constants => [ qw(
+      DEBUG9
+      DEBUG8
+      DEBUG7
+      DEBUG6
+      DEBUG5
+      DEBUG4
+      DEBUG3
+      DEBUG2
+      DEBUG1
       DEBUG
       INFO
       WARNING
@@ -98,6 +107,15 @@ use Time::HiRes qw/gettimeofday/;
 use Sys::Syslog;
 
 use constant {
+  DEBUG9 => 9,
+  DEBUG8 => 8,
+  DEBUG7 => 7,
+  DEBUG6 => 6,
+  DEBUG5 => 5,
+  DEBUG4 => 4,
+  DEBUG3 => 3,
+  DEBUG2 => 2,
+  DEBUG1 => 1,
   DEBUG => 1,
   INFO => 0,
   WARNING => -1,
@@ -108,7 +126,16 @@ use constant {
 };
 
 our %codes = (
-    &DEBUG => 'DBG',
+    &DEBUG9 => 'DB9',
+    &DEBUG8 => 'DB8',
+    &DEBUG7 => 'DB7',
+    &DEBUG6 => 'DB6',
+    &DEBUG5 => 'DB5',
+    &DEBUG4 => 'DB4',
+    &DEBUG3 => 'DB3',
+    &DEBUG2 => 'DB2',
+    &DEBUG1 => 'DB1',
+    &DEBUG => 'DB1',
     &INFO => 'INF',
     &WARNING => 'WAR',
     &ERROR => 'ERR',
@@ -332,9 +359,9 @@ sub reinitialise {
 sub limit {
   my $this = shift;
   my $level = shift;
-  return(DEBUG) if $level > DEBUG;
-  return(NOLOG) if $level < NOLOG;
-  return($level);
+  return DEBUG9 if $level > DEBUG9;
+  return NOLOG if $level < NOLOG;
+  return $level;
 }
 
 sub getTargettedEnv {
@@ -456,9 +483,9 @@ sub fileLevel {
   if ( defined($fileLevel) ) {
     $fileLevel = $this->limit($fileLevel);
     # The filename might have changed, so always close and re-open
-    $this->closeFile() if ( $this->{fileLevel} > NOLOG );
+    $this->closeFile() if $this->{fileLevel} > NOLOG;
     $this->{fileLevel} = $fileLevel;
-    $this->openFile() if ( $this->{fileLevel} > NOLOG );
+    $this->openFile() if $this->{fileLevel} > NOLOG;
   }
   return $this->{fileLevel};
 }
@@ -499,13 +526,14 @@ sub logFile {
 
 sub openFile {
   my $this = shift;
+	
   if ( open($LOGFILE, '>>', $this->{logFile}) ) {
     $LOGFILE->autoflush() if $this->{autoFlush};
 
     my $webUid = (getpwnam($ZoneMinder::Config::Config{ZM_WEB_USER}))[2];
-    Error("Can't get uid for $ZoneMinder::Config::Config{ZM_WEB_USER}") if ! defined $webUid;
+    Error('Can\'t get uid for '.$ZoneMinder::Config::Config{ZM_WEB_USER}) if ! defined $webUid;
     my $webGid = (getgrnam($ZoneMinder::Config::Config{ZM_WEB_GROUP}))[2];
-    Error("Can't get gid for $ZoneMinder::Config::Config{ZM_WEB_USER}") if ! defined $webGid;
+    Error('Can\'t get gid for '.$ZoneMinder::Config::Config{ZM_WEB_USER}) if ! defined $webGid;
     if ( $> == 0 ) {
       # If we are root, we want to make sure that www-data or whatever owns the file
       chown($webUid, $webGid, $this->{logFile} ) or
@@ -519,7 +547,6 @@ sub openFile {
 }
 
 sub closeFile {
-  #my $this = shift;
   close($LOGFILE) if fileno($LOGFILE);
 }
 
@@ -610,6 +637,7 @@ sub logInit( ;@ ) {
   my %options = @_ ? @_ : ();
   $logger = ZoneMinder::Logger->new() if !$logger;
   $logger->initialise(%options);
+  logSetSignal();
 }
 
 sub logReinit {
@@ -626,12 +654,26 @@ sub logHupHandler {
   $do_log_rotate = 1;
 }
 
+sub logUSR1Handler {
+  $logger->level($logger->level()+1);
+  Info('Logger - Level changed to '. $logger->level() . '=>'.$codes{$logger->level()});
+}
+
+sub logUSR2Handler {
+  $logger->level($logger->level()-1);
+  Info('Logger - Level changed to '. $logger->level() . '=>'.$codes{$logger->level()});
+}
+
 sub logSetSignal {
   $SIG{HUP} = \&logHupHandler;
+  $SIG{USR1} = \&logUSR1Handler;
+  $SIG{USR2} = \&logUSR2Handler;
 }
 
 sub logClearSignal {
   $SIG{HUP} = 'DEFAULT';
+  $SIG{USR1} = 'DEFAULT';
+  $SIG{USR2} = 'DEFAULT';
 }
 
 sub logLevel {
@@ -674,38 +716,34 @@ sub Dump {
 
 sub debug {
   my $log = shift;
-  $log->logPrint(DEBUG, @_, caller);
+  $log->logPrint(DEBUG1, @_, caller);
 }
 
-sub Debug( @ ) {
-  fetch()->logPrint(DEBUG, @_, caller);
+sub Debug {
+  fetch()->logPrint(
+    (@_ == 1 ? (DEBUG1, @_) : @_),
+    caller);
 }
 
-sub Info( @ ) {
-  fetch()->logPrint(INFO, @_, caller);
-}
+sub Info { fetch()->logPrint(INFO, @_, caller); }
 sub info {
   my $log = shift;
   $log->logPrint(INFO, @_, caller);
 }
 
-sub Warning( @ ) {
-  fetch()->logPrint(WARNING, @_, caller);
-}
+sub Warning { fetch()->logPrint(WARNING, @_, caller); }
 sub warn {
   my $log = shift;
   $log->logPrint(WARNING, @_, caller);
 }
 
-sub Error( @ ) {
-  fetch()->logPrint(ERROR, @_, caller);
-}
+sub Error { fetch()->logPrint(ERROR, @_, caller); }
 sub error {
   my $log = shift;
   $log->logPrint(ERROR, @_, caller);
 }
 
-sub Fatal( @ ) {
+sub Fatal {
   my $this = fetch();
   $this->logPrint(FATAL, @_, caller);
   if ( $SIG{TERM} and ( $SIG{TERM} ne 'DEFAULT' ) ) {
@@ -720,7 +758,7 @@ sub Fatal( @ ) {
   exit(-1);
 }
 
-sub Panic( @ ) {
+sub Panic {
   fetch()->logPrint(PANIC, @_, caller);
   confess($_[0]);
 }
