@@ -31,6 +31,7 @@ use warnings;
 require ZoneMinder::Base;
 require ZoneMinder::Object;
 require ZoneMinder::Server;
+require ZoneMinder::General;
 
 use parent qw(Exporter ZoneMinder::Object);
 
@@ -46,20 +47,18 @@ use ZoneMinder::Database qw(:all);
 
 use POSIX;
 
-use vars qw/ $table $primary_key %fields/;
+use vars qw/ $table $primary_key %fields $debug/;
+$debug = 0;
 $table = 'Storage';
 $primary_key = 'Id';
-#__PACKAGE__->table('Storage');
-#__PACKAGE__->primary_key('Id');
 %fields = map { $_ => $_ } qw( Id Name Path DoDelete ServerId Type Url DiskSpace Scheme );
 
-
 sub Path {
   if ( @_ > 1 ) {
     $_[0]{Path} = $_[1];
   }
   if ( ! ( $_[0]{Id} or $_[0]{Path} ) ) {
-    $_[0]{Path} = ($Config{ZM_DIR_EVENTS}=~/^\//) ? $Config{ZM_DIR_EVENTS} : ($Config{ZM_PATH_WEB}.'/'.$Config{ZM_DIR_EVENTS})
+    $_[0]{Path} = ($Config{ZM_DIR_EVENTS}=~/^\//) ? $Config{ZM_DIR_EVENTS} : ($Config{ZM_PATH_WEB}.'/'.$Config{ZM_DIR_EVENTS});
   }
   return $_[0]{Path};
 } # end sub Path
@@ -88,18 +87,64 @@ sub Server {
   return $$self{Server};
 }
 
+sub delete_path {
+  my $self = shift;
+  my $path = shift;
+
+  my $deleted = 0;
+  
+  Debug("Delete $path");
+  if ($$self{Type} and ( $$self{Type} eq 's3fs' )) {
+    my $url = $$self{Url};
+    $url =~ s/^(s3|s3fs):\/\///ig;
+    my ( $aws_id, $aws_secret, $aws_host, $aws_bucket, $subpath ) = ( $url =~ /^\s*([^:]+):([^@]+)@([^\/]*)\/([^\/]+)(\/.+)?\s*$/ );
+    Debug("S3 url parsed to id:$aws_id secret:$aws_secret host:$aws_host, bucket:$aws_bucket, subpath:$subpath\n from $url");
+    eval {
+      require Net::Amazon::S3;
+      my $s3 = Net::Amazon::S3->new( {
+          aws_access_key_id     => $aws_id,
+          aws_secret_access_key => $aws_secret,
+          ( $aws_host ? ( host => $aws_host ) : () ),
+          authorization_method => 'Net::Amazon::S3::Signature::V4',
+        });
+      my $bucket = $s3->bucket($aws_bucket);
+      if ( ! $bucket ) {
+        Error("S3 bucket $bucket not found.");
+        die;
+      }
+      if ( $bucket->delete_key($subpath.$path) ) {
+        $deleted = 1;
+      } else {
+        Error('Failed to delete from S3:'.$s3->err . ': ' . $s3->errstr);
+      }
+    };
+    Error($@) if $@;
+  } # end if s3fs
+
+  if ( !$deleted ) {
+    my $storage_path = $self->Path();
+    ( $storage_path ) = ( $storage_path =~ /^(.*)$/ ); # De-taint
+    ( $path ) = ( $path =~ /^(.*)$/ ); # De-taint
+    my $command = "/bin/rm -rf $storage_path/$path 2>&1";
+    if (ZoneMinder::General::executeShellCommand($command)) {
+      Error("Error deleting event directory at $storage_path/$path");
+    }
+  }
+}
+
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
-ZoneMinder::Database - Perl extension for blah blah blah
+ZoneMinder::Storage - Perl modules for Storage objects
 
 =head1 SYNOPSIS
 
   use ZoneMinder::Storage;
-  blah blah blah
+  my $Storage = ZoneMinder::Storage->find_one(Name=>'Default');
+  my @S3Areas = ZoneMinder::Stroage->find(Type=>'s3fs');
+  etc...
 
 =head1 DESCRIPTION
 
@@ -128,11 +173,11 @@ If you have a web site set up for your module, mention it here.
 
 =head1 AUTHOR
 
-Philip Coombes, E<lt>philip.coombes@zoneminder.comE<gt>
+Isaac Connor, E<lt>isaac@zoneminder.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2001-2008  Philip Coombes
+Copyright (C) 2022 ZoneMinder Inc
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.3 or,
