@@ -20,14 +20,14 @@
 #ifndef ZM_CAMERA_H
 #define ZM_CAMERA_H
 
-#include <sys/types.h>
-#include <sys/ioctl.h>
-
 #include "zm_image.h"
+#include <sys/ioctl.h>
+#include <sys/types.h>
 
-class Camera;
+#include <memory>
 
-#include "zm_monitor.h"
+class Monitor;
+class ZMPacket;
 
 //
 // Abstract base class for cameras. This is intended just to express
@@ -35,10 +35,9 @@ class Camera;
 //
 class Camera {
 protected:
-  typedef enum { LOCAL_SRC, REMOTE_SRC, FILE_SRC, FFMPEG_SRC, LIBVLC_SRC, CURL_SRC } SourceType;
+  typedef enum { LOCAL_SRC, REMOTE_SRC, FILE_SRC, FFMPEG_SRC, LIBVLC_SRC, CURL_SRC, VNC_SRC } SourceType;
 
-  unsigned int  monitor_id;
-  Monitor *     monitor; // Null on instantiation, set as soon as possible.
+  const Monitor *monitor;
   SourceType    type;
   unsigned int  width;
   unsigned int  linesize;
@@ -53,15 +52,37 @@ protected:
   int           contrast;
   bool          capture;
   bool          record_audio;
+  int                 mVideoStreamId;
+  int                 mAudioStreamId;
+  AVCodecContext      *mVideoCodecContext;
+  AVCodecContext      *mAudioCodecContext;
+  AVStream *mVideoStream;
+  AVStream *mAudioStream;
+  AVFormatContext *mFormatContext; // One for video, one for audio
+  AVFormatContext *mSecondFormatContext; // One for video, one for audio
+  int64_t     mFirstVideoPTS;
+  int64_t     mFirstAudioPTS;
+  int64_t     mLastVideoPTS;
+  int64_t     mLastAudioPTS;
   unsigned int  bytes;
 
 public:
-  Camera( unsigned int p_monitor_id, SourceType p_type, unsigned int p_width, unsigned int p_height, int p_colours, int p_subpixelorder, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture, bool p_record_audio );
+  Camera(
+      const Monitor* monitor,
+      SourceType p_type,
+      unsigned int p_width,
+      unsigned int p_height,
+      int p_colours,
+      int p_subpixelorder,
+      int p_brightness,
+      int p_contrast,
+      int p_hue,
+      int p_colour,
+      bool p_capture,
+      bool p_record_audio
+      );
   virtual ~Camera();
 
-  unsigned int getId() const { return monitor_id; }
-  Monitor *getMonitor();
-  void  setMonitor( Monitor *p_monitor );
   SourceType Type() const { return type; }
   bool IsLocal() const { return type == LOCAL_SRC; }
   bool IsRemote() const { return type == REMOTE_SRC; }
@@ -69,6 +90,7 @@ public:
   bool IsFfmpeg() const { return type == FFMPEG_SRC; }
   bool IsLibvlc() const { return type == LIBVLC_SRC; }
   bool IscURL() const { return type == CURL_SRC; }
+  bool IsVNC() const { return type == VNC_SRC; }
   unsigned int Width() const { return width; }
   unsigned int LineSize() const { return linesize; }
   unsigned int Height() const { return height; }
@@ -77,6 +99,20 @@ public:
   unsigned int Pixels() const { return pixels; }
   unsigned long long ImageSize() const { return imagesize; }
   unsigned int Bytes() const { return bytes; };
+  int getFrequency() {
+#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
+    return mAudioStream ? mAudioStream->codecpar->sample_rate : -1;
+#else
+    return mAudioStream ? mAudioStream->codec->sample_rate : -1;
+#endif
+  }
+  int getChannels() {
+#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
+    return mAudioStream ? mAudioStream->codecpar->channels : -1;
+#else
+    return mAudioStream ? mAudioStream->codec->channels : -1;
+#endif
+  }
 
   virtual int Brightness( int/*p_brightness*/=-1 ) { return -1; }
   virtual int Hue( int/*p_hue*/=-1 ) { return -1; }
@@ -90,11 +126,17 @@ public:
     //return (type == FFMPEG_SRC )||(type == REMOTE_SRC);
   }
 
+  virtual AVStream      *getVideoStream();
+  virtual AVStream      *getAudioStream() { return mAudioStream; };
+  virtual AVCodecContext     *getVideoCodecContext() { return mVideoCodecContext; };
+  virtual AVCodecContext     *getAudioCodecContext() { return mAudioCodecContext; };
+  int            getVideoStreamId() { return mVideoStreamId; };
+  int            getAudioStreamId() { return mAudioStreamId; };
+
   virtual int PrimeCapture() { return 0; }
   virtual int PreCapture() = 0;
-  virtual int Capture(Image &image) = 0;
+  virtual int Capture(std::shared_ptr<ZMPacket> &p) = 0;
   virtual int PostCapture() = 0;
-  virtual int CaptureAndRecord(Image &image, timeval recording, char* event_directory) = 0;
   virtual int Close() = 0;
 };
 
