@@ -99,7 +99,7 @@ class Event {
 
     void createNotes(std::string &notes);
 
-    std::queue<ZMLockedPacket *> packet_queue;
+    std::queue<std::shared_ptr<ZMPacket>> packet_queue;
     std::mutex packet_queue_mutex;
     std::condition_variable packet_queue_condition;
 
@@ -128,7 +128,7 @@ class Event {
     const struct timeval &StartTime() const { return start_time; }
     const struct timeval &EndTime() const { return end_time; }
 
-    void AddPacket(ZMLockedPacket *);
+    void AddPacket(const std::shared_ptr<ZMPacket> &p);
     void AddPacket_(const std::shared_ptr<ZMPacket> &p);
     bool WritePacket(const std::shared_ptr<ZMPacket> &p);
     bool SendFrameImage(const Image *image, bool alarm_frame=false);
