@@ -125,6 +125,9 @@ extern "C" {
 // AVCODEC
 #if HAVE_LIBAVCODEC_AVCODEC_H
 #include <libavcodec/avcodec.h>
+#elif HAVE_FFMPEG_AVCODEC_H
+#include <ffmpeg/avcodec.h>
+#endif /* HAVE_LIBAVCODEC_AVCODEC_H */
 
 /*
  * LIBAVCODEC_VERSION_CHECK checks for the right version of libav and FFmpeg
@@ -136,10 +139,6 @@ extern "C" {
     ( (LIBAVCODEC_VERSION_MICRO <  100 && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
       (LIBAVCODEC_VERSION_MICRO >= 100 && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
 
-#elif HAVE_FFMPEG_AVCODEC_H
-#include <ffmpeg/avcodec.h>
-#endif /* HAVE_LIBAVCODEC_AVCODEC_H */
-
 #if defined(HAVE_LIBAVCODEC_AVCODEC_H)
 #if LIBAVCODEC_VERSION_CHECK(54, 25, 0, 51, 100)
     #define _AVCODECID AVCodecID
@@ -435,7 +434,7 @@ void zm_dump_codecpar(const AVCodecParameters *par);
   #define av_frame_free( input_avframe ) av_freep( input_avframe )
 #endif
 
-int check_sample_fmt(AVCodec *codec, enum AVSampleFormat sample_fmt);
+int check_sample_fmt(const AVCodec *codec, enum AVSampleFormat sample_fmt);
 enum AVPixelFormat fix_deprecated_pix_fmt(enum AVPixelFormat );
 
 bool is_video_stream(const AVStream *);
