@@ -64,7 +64,7 @@ public:
   } Function;
 
   typedef enum {
-    LOCAL,
+    LOCAL=1,
     REMOTE,
     FILE,
     FFMPEG,
@@ -100,7 +100,7 @@ public:
   } Deinterlace;
 
   typedef enum {
-    UNKNOWN=-1,
+    UNKNOWN=0,
     IDLE,
     PREALARM,
     ALARM,
