@@ -407,10 +407,8 @@ bool MonitorStream::sendFrame(Image *image, const timeval &timestamp) {
         ||
         (fwrite(img_buffer, img_buffer_size, 1, stdout) != 1)
        ) {
-      if ( !zm_terminate ) {
-        // If the pipe was closed, we will get signalled SIGPIPE to exit, which will set zm_terminate
-        Warning("Unable to send stream frame: %s", strerror(errno));
-      }
+      // If the pipe was closed, we will get signalled SIGPIPE to exit, which will set zm_terminate
+      Debug(1, "Unable to send stream frame: %s, zm_terminate: %d", strerror(errno), zm_terminate);
       return false;
     }
     fputs("\r\n", stdout);
