@@ -17,12 +17,14 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 // 
 
-#include "zm.h"
+#include "zm_sdp.h"
+
+#include "zm_config.h"
+#include "zm_exception.h"
+#include "zm_logger.h"
 
 #if HAVE_LIBAVFORMAT
 
-#include "zm_sdp.h"
-
 #if (LIBAVCODEC_VERSION_CHECK(52, 64, 0, 64, 0) || LIBAVUTIL_VERSION_CHECK(50, 14, 0, 14, 0))
 SessionDescriptor::StaticPayloadDesc SessionDescriptor::smStaticPayloads[] = {
   { 0, "PCMU",   AVMEDIA_TYPE_AUDIO,   AV_CODEC_ID_PCM_MULAW,  8000,  1 },
@@ -105,7 +107,7 @@ SessionDescriptor::ConnInfo::ConnInfo( const std::string &connInfo ) :
   mTtl( 16 ),
   mNoAddresses( 0 )
 {
-  StringVector tokens = split(connInfo, " ");
+  StringVector tokens = Split(connInfo, " ");
   if ( tokens.size() < 3 )
     throw Exception( "Unable to parse SDP connection info from '"+connInfo+"'" );
   mNetworkType = tokens[0];
@@ -114,7 +116,7 @@ SessionDescriptor::ConnInfo::ConnInfo( const std::string &connInfo ) :
   mAddressType = tokens[1];
   if ( mAddressType != "IP4" && mAddressType != "IP6" )
     throw Exception( "Invalid SDP address type '"+mAddressType+"' in connection info '"+connInfo+"'" );
-  StringVector addressTokens = split( tokens[2], "/" );
+  StringVector addressTokens = Split(tokens[2], "/");
   if ( addressTokens.size() < 1 ) 
     throw Exception( "Invalid SDP address '"+tokens[2]+"' in connection info '"+connInfo+"'" );
   mAddress = addressTokens[0];
@@ -127,7 +129,7 @@ SessionDescriptor::ConnInfo::ConnInfo( const std::string &connInfo ) :
 SessionDescriptor::BandInfo::BandInfo( const std::string &bandInfo ) :
   mValue( 0 )
 {
-  StringVector tokens = split( bandInfo, ":" );
+  StringVector tokens = Split(bandInfo, ":");
   if ( tokens.size() < 2 )
     throw Exception( "Unable to parse SDP bandwidth info from '"+bandInfo+"'" );
   mType = tokens[0];
@@ -152,18 +154,18 @@ SessionDescriptor::MediaDescriptor::MediaDescriptor(
   mWidth( 0 ),
   mHeight( 0 ),
   mSprops( "" ),
-  mConnInfo( 0 )
+  mConnInfo( nullptr )
 {
 }
 
 SessionDescriptor::SessionDescriptor( const std::string &url, const std::string &sdp ) : 
   mUrl( url ),
-  mConnInfo( 0 ),
-  mBandInfo( 0 )
+  mConnInfo( nullptr ),
+  mBandInfo( nullptr )
 {
-  MediaDescriptor *currMedia = 0;
+  MediaDescriptor *currMedia = nullptr;
 
-  StringVector lines = split( sdp, "\r\n" );
+  StringVector lines = Split(sdp, "\r\n");
   for ( StringVector::const_iterator iter = lines.begin(); iter != lines.end(); ++iter ) {
     std::string line = *iter;
     if ( line.empty() )
@@ -206,7 +208,7 @@ SessionDescriptor::SessionDescriptor( const std::string &url, const std::string
       case 'a' :
       {
         mAttributes.push_back( line );
-        StringVector tokens = split( line, ":", 2 );
+        StringVector tokens = Split(line, ":", 2);
         std::string attrName = tokens[0];
         if ( currMedia ) {
           if ( attrName == "control" ) {
@@ -218,14 +220,12 @@ SessionDescriptor::SessionDescriptor( const std::string &url, const std::string
             // a=rtpmap:96 MP4V-ES/90000
             if ( tokens.size() < 2 )
               throw Exception( "Unable to parse SDP rtpmap attribute '"+line+"' for media '"+currMedia->getType()+"'" );
-            StringVector attrTokens = split( tokens[1], " " );
+            StringVector attrTokens = Split(tokens[1], " ");
             int payloadType = atoi(attrTokens[0].c_str());
             if ( payloadType != currMedia->getPayloadType() )
               throw Exception( stringtf( "Payload type mismatch, expected %d, got %d in '%s'", currMedia->getPayloadType(), payloadType, line.c_str() ) );
-            std::string payloadDesc = attrTokens[1];
-            //currMedia->setPayloadType( payloadType );
             if ( attrTokens.size() > 1 ) {
-              StringVector payloadTokens = split( attrTokens[1], "/" );
+              StringVector payloadTokens = Split(attrTokens[1], "/");
               std::string payloadDesc = payloadTokens[0];
               int payloadClock = atoi(payloadTokens[1].c_str());
               currMedia->setPayloadDesc( payloadDesc );
@@ -235,13 +235,13 @@ SessionDescriptor::SessionDescriptor( const std::string &url, const std::string
             // a=framesize:96 320-240
             if ( tokens.size() < 2 )
               throw Exception("Unable to parse SDP framesize attribute '"+line+"' for media '"+currMedia->getType()+"'");
-            StringVector attrTokens = split(tokens[1], " ");
+            StringVector attrTokens = Split(tokens[1], " ");
             int payloadType = atoi(attrTokens[0].c_str());
             if ( payloadType != currMedia->getPayloadType() )
               throw Exception( stringtf("Payload type mismatch, expected %d, got %d in '%s'",
                     currMedia->getPayloadType(), payloadType, line.c_str()));
             //currMedia->setPayloadType( payloadType );
-            StringVector sizeTokens = split(attrTokens[1], "-");
+            StringVector sizeTokens = Split(attrTokens[1], "-");
             int width = atoi(sizeTokens[0].c_str());
             int height = atoi(sizeTokens[1].c_str());
             currMedia->setFrameSize(width, height);
@@ -255,16 +255,16 @@ SessionDescriptor::SessionDescriptor( const std::string &url, const std::string
             // a=fmtp:96 profile-level-id=247; config=000001B0F7000001B509000001000000012008D48D8803250F042D14440F
             if ( tokens.size() < 2 )
               throw Exception("Unable to parse SDP fmtp attribute '"+line+"' for media '"+currMedia->getType()+"'");
-            StringVector attrTokens = split(tokens[1], " ", 2);
+            StringVector attrTokens = Split(tokens[1], " ", 2);
             int payloadType = atoi(attrTokens[0].c_str());
             if ( payloadType != currMedia->getPayloadType() )
               throw Exception(stringtf("Payload type mismatch, expected %d, got %d in '%s'",
                     currMedia->getPayloadType(), payloadType, line.c_str()));
             //currMedia->setPayloadType( payloadType );
             if ( attrTokens.size() > 1 ) {
-              StringVector attr2Tokens = split( attrTokens[1], "; " );
+              StringVector attr2Tokens = Split(attrTokens[1], "; ");
               for ( unsigned int i = 0; i < attr2Tokens.size(); i++ ) {
-                StringVector attr3Tokens = split( attr2Tokens[i], "=" );
+                StringVector attr3Tokens = Split(attr2Tokens[i], "=");
                 //Info( "Name = %s, Value = %s", attr3Tokens[0].c_str(), attr3Tokens[1].c_str() );
                 if ( attr3Tokens[0] == "profile-level-id" ) {
                 } else if ( attr3Tokens[0] == "config" ) {
@@ -274,7 +274,9 @@ SessionDescriptor::SessionDescriptor( const std::string &url, const std::string
                     Debug(4, "sprop-parameter-sets value %s", c);
                   currMedia->setSprops(std::string(c));
                 } else {
-                  Debug( 3, "Ignoring SDP fmtp attribute '%s' for media '%s'", attr3Tokens[0].c_str(), currMedia->getType().c_str() )
+                  Debug(3, "Ignoring SDP fmtp attribute '%s' for media '%s'",
+                        attr3Tokens[0].c_str(),
+                        currMedia->getType().c_str());
                 }
               }
             }
@@ -292,13 +294,13 @@ SessionDescriptor::SessionDescriptor( const std::string &url, const std::string
       }
       case 'm' :
       {
-        StringVector tokens = split(line, " ");
+        StringVector tokens = Split(line, " ");
         if ( tokens.size() < 4 )
           throw Exception("Can't parse SDP media description '"+line+"'");
         std::string mediaType = tokens[0];
         if ( mediaType != "audio" && mediaType != "video"  && mediaType != "application" )
           throw Exception("Unsupported media type '"+mediaType+"' in SDP media attribute '"+line+"'");
-        StringVector portTokens = split(tokens[1], "/");
+        StringVector portTokens = Split(tokens[1], "/");
         int mediaPort = atoi(portTokens[0].c_str());
         int mediaNumPorts = 1;
         if ( portTokens.size() > 1 )
@@ -344,14 +346,12 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const {
 #if !LIBAVFORMAT_VERSION_CHECK(53, 10, 0, 17, 0)
     AVStream *stream = av_new_stream(formatContext, i);
 #else
-    AVStream *stream = avformat_new_stream(formatContext, NULL);
+    AVStream *stream = avformat_new_stream(formatContext, nullptr);
     stream->id = i;
 #endif
 
 #if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
-    AVCodecContext *codec_context = avcodec_alloc_context3(NULL);
-    avcodec_parameters_to_context(codec_context, stream->codecpar);
-    stream->codec = codec_context;
+    AVCodecContext *codec_context = avcodec_alloc_context3(nullptr);
 #else
     AVCodecContext *codec_context = stream->codec;
 #endif
@@ -382,38 +382,39 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const {
 #endif
     if ( mediaDesc->getPayloadType() < PAYLOAD_TYPE_DYNAMIC ) {
       // Look in static table
-      for ( unsigned int i = 0; i < (sizeof(smStaticPayloads)/sizeof(*smStaticPayloads)); i++ ) {
-        if ( smStaticPayloads[i].payloadType == mediaDesc->getPayloadType() ) {
-          Debug( 1, "Got static payload type %d, %s", smStaticPayloads[i].payloadType, smStaticPayloads[i].payloadName );
+      for ( unsigned int j = 0; j < (sizeof(smStaticPayloads)/sizeof(*smStaticPayloads)); j++ ) {
+        if ( smStaticPayloads[j].payloadType == mediaDesc->getPayloadType() ) {
+          Debug( 1, "Got static payload type %d, %s", smStaticPayloads[j].payloadType, smStaticPayloads[j].payloadName );
 #if LIBAVCODEC_VERSION_CHECK(55, 50, 3, 60, 103)
-          codec_name = std::string(smStaticPayloads[i].payloadName);
+          codec_name = std::string(smStaticPayloads[j].payloadName);
 #else
-          strncpy(codec_context->codec_name, smStaticPayloads[i].payloadName, sizeof(codec_context->codec_name));
+          strncpy(codec_context->codec_name, smStaticPayloads[j].payloadName, sizeof(codec_context->codec_name));
 #endif
-          codec_context->codec_type = smStaticPayloads[i].codecType;
-          codec_context->codec_id = smStaticPayloads[i].codecId;
-          codec_context->sample_rate = smStaticPayloads[i].clockRate;
+          codec_context->codec_type = smStaticPayloads[j].codecType;
+          codec_context->codec_id = smStaticPayloads[j].codecId;
+          codec_context->sample_rate = smStaticPayloads[j].clockRate;
           break;
         }
       }
     } else {
       // Look in dynamic table
-      for ( unsigned int i = 0; i < (sizeof(smDynamicPayloads)/sizeof(*smDynamicPayloads)); i++ ) {
-        if ( smDynamicPayloads[i].payloadName == mediaDesc->getPayloadDesc() ) {
-          Debug(1, "Got dynamic payload type %d, %s", mediaDesc->getPayloadType(), smDynamicPayloads[i].payloadName);
+      for ( unsigned int j = 0; j < (sizeof(smDynamicPayloads)/sizeof(*smDynamicPayloads)); j++ ) {
+        if ( smDynamicPayloads[j].payloadName == mediaDesc->getPayloadDesc() ) {
+          Debug(1, "Got dynamic payload type %d, %s", mediaDesc->getPayloadType(), smDynamicPayloads[j].payloadName);
 #if LIBAVCODEC_VERSION_CHECK(55, 50, 3, 60, 103)
-          codec_name = std::string(smStaticPayloads[i].payloadName);
+          codec_name = std::string(smStaticPayloads[j].payloadName);
 #else
-          strncpy(codec_context->codec_name, smDynamicPayloads[i].payloadName, sizeof(codec_context->codec_name));
+          strncpy(codec_context->codec_name, smDynamicPayloads[j].payloadName, sizeof(codec_context->codec_name));
 #endif
-          codec_context->codec_type = smDynamicPayloads[i].codecType;
-          codec_context->codec_id = smDynamicPayloads[i].codecId;
+          codec_context->codec_type = smDynamicPayloads[j].codecType;
+          codec_context->codec_id = smDynamicPayloads[j].codecId;
           codec_context->sample_rate = mediaDesc->getClock();
           break;
         }
       }
     } /// end if static or dynamic
 
+
 #if LIBAVCODEC_VERSION_CHECK(55, 50, 3, 60, 103)
     if ( codec_name.empty() )
 #else
@@ -422,7 +423,6 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const {
     {
       Warning( "Can't find payload details for %s payload type %d, name %s",
           mediaDesc->getType().c_str(), mediaDesc->getPayloadType(), mediaDesc->getPayloadDesc().c_str() );
-      //return( 0 );
     }
     if ( mediaDesc->getWidth() )
       codec_context->width = mediaDesc->getWidth();
@@ -431,12 +431,12 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const {
     if ( codec_context->codec_id == AV_CODEC_ID_H264 && mediaDesc->getSprops().size()) {
       uint8_t start_sequence[]= { 0, 0, 1 };
       codec_context->extradata_size= 0;
-      codec_context->extradata= NULL;
+      codec_context->extradata= nullptr;
       char pvalue[1024], *value = pvalue;
     
       strcpy(pvalue, mediaDesc->getSprops().c_str());
     
-      while (*value) {
+      while ( *value ) {
         char base64packet[1024];
         uint8_t decoded_packet[1024];
         uint32_t packet_size;
@@ -451,9 +451,9 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const {
         if ( *value == ',' )
           value++;
 
-        packet_size= av_base64_decode(decoded_packet, (const char *)base64packet, (int)sizeof(decoded_packet));
+        packet_size = av_base64_decode(decoded_packet, (const char *)base64packet, (int)sizeof(decoded_packet));
         Hexdump(4, (char *)decoded_packet, packet_size);
-        if (packet_size) {
+        if ( packet_size ) {
           uint8_t *dest = 
           (uint8_t *)av_malloc(packet_size + sizeof(start_sequence) +
                        codec_context->extradata_size +
@@ -490,7 +490,10 @@ AVFormatContext *SessionDescriptor::generateFormatContext() const {
         }
       }
     }
-  }
+#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
+    avcodec_parameters_from_context(stream->codecpar, codec_context);
+#endif
+  }  // end foreach mediaList
 
   return formatContext;
 }
