@@ -210,7 +210,10 @@ int main(int argc, const char *argv[], char **envp) {
       }
     }
     if ( !user ) {
-      fputs("HTTP/1.0 403 Forbidden\r\n\r\n", stdout);
+      if (nph) {
+        fputs("HTTP/1.0 403 Forbidden\r\n\r\n", stdout);
+      }
+      fputs("Status: 403\r\nContent-Type: text/html\r\n", stdout);
 
       const char *referer = getenv("HTTP_REFERER");
       Error("Unable to authenticate user from %s", referer);
@@ -221,7 +224,10 @@ int main(int argc, const char *argv[], char **envp) {
     if ( !ValidateAccess(user, monitor_id) ) {
       delete user;
       user = nullptr;
-      fputs("HTTP/1.0 403 Forbidden\r\n\r\n", stdout);
+      if (nph) {
+        fputs("HTTP/1.0 403 Forbidden\r\n\r\n", stdout);
+      }
+      fputs("Status: 403\r\nContent-Type: text/html\r\n\r\n", stdout);
       logTerm();
       zmDbClose();
       return 0;
@@ -335,8 +341,8 @@ int main(int argc, const char *argv[], char **envp) {
 
   Debug(1, "Terminating");
   Image::Deinitialise();
-  logTerm();
   dbQueue.stop();
+  logTerm();
   zmDbClose();
 
   return 0;
