@@ -336,6 +336,8 @@ class Monitor extends ZM_Object {
 
       if ($mode == 'stop') {
         daemonControl('stop', 'zmc', $zmcArgs);
+      } else if ($mode == 'reload') {
+        daemonControl('reload', 'zmc', $zmcArgs);
       } else {
         if ($mode == 'restart') {
           daemonControl('stop', 'zmc', $zmcArgs);
@@ -636,7 +638,7 @@ class Monitor extends ZM_Object {
         return false;
       }
 
-      $cmd = getZmuCommand($cmd.' -m '.$this->{'Id'});
+      $cmd = getZmuCommand($cmd.' -m '.validCardinal($this->{'Id'}));
       $output = shell_exec($cmd);
       Debug("Running $cmd output: $output");
       return $output;
