@@ -18,41 +18,41 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
+global $error_message;
 // Event scope actions, view permissions only required
-if ( !canView('Events') ) {
-  ZM\Warning('You do not have permission to view Events.');
+if (!canView('Events')) {
+	$error_message = 'You do not have permission to view Events.';
+	ZM\Warning($error_message);
   return;
 }
 
-if ( isset($_REQUEST['object']) and ( $_REQUEST['object'] == 'filter' ) ) {
-  if ( $action == 'addterm' ) {
+if (isset($_REQUEST['object']) and ($_REQUEST['object'] == 'filter')) {
+  if ($action == 'addterm') {
     $_REQUEST['filter'] = addFilterTerm($_REQUEST['filter'], $_REQUEST['line']);
-  } elseif ( $action == 'delterm' ) {
+  } else if ($action == 'delterm') {
     $_REQUEST['filter'] = delFilterTerm($_REQUEST['filter'], $_REQUEST['line']);
-  } else if ( canEdit('Events') ) {
-
+  } else if (canEdit('Events')) {
     require_once('includes/Filter.php');
     $filter = new ZM\Filter($_REQUEST['Id']);
 
-    if ( $action == 'delete' ) {
-      if ( !empty($_REQUEST['Id']) ) {
-          if ( $filter->Background() ) {
+    if ($action == 'delete') {
+      if (!empty($_REQUEST['Id'])) {
+          if ($filter->Background()) {
             $filter->control('stop');
           }
           $filter->delete();
-
       } else {
         ZM\Error('No filter id passed when deleting');
       }
-    } else if ( ( $action == 'Save' ) or ( $action == 'SaveAs' ) or ( $action == 'execute' ) ) {
-
-      $sql = '';
+    } else if (( $action == 'Save' ) or ( $action == 'SaveAs' ) or ( $action == 'execute' )) {
       $_REQUEST['filter']['Query']['sort_field'] = validStr($_REQUEST['filter']['Query']['sort_field']);
       $_REQUEST['filter']['Query']['sort_asc'] = validStr($_REQUEST['filter']['Query']['sort_asc']);
       $_REQUEST['filter']['Query']['limit'] = validInt($_REQUEST['filter']['Query']['limit']);
       
       $_REQUEST['filter']['AutoCopy'] = empty($_REQUEST['filter']['AutoCopy']) ? 0 : 1;
+      $_REQUEST['filter']['AutoCopyTo'] = empty($_REQUEST['filter']['AutoCopyTo']) ? 0 : $_REQUEST['filter']['AutoCopyTo'];
       $_REQUEST['filter']['AutoMove'] = empty($_REQUEST['filter']['AutoMove']) ? 0 : 1;
+      $_REQUEST['filter']['AutoMoveTo'] = empty($_REQUEST['filter']['AutoMoveTo']) ? 0 : $_REQUEST['filter']['AutoMoveTo'];
       $_REQUEST['filter']['AutoArchive'] = empty($_REQUEST['filter']['AutoArchive']) ? 0 : 1;
       $_REQUEST['filter']['AutoVideo'] = empty($_REQUEST['filter']['AutoVideo']) ? 0 : 1;
       $_REQUEST['filter']['AutoUpload'] = empty($_REQUEST['filter']['AutoUpload']) ? 0 : 1;
@@ -64,39 +64,39 @@ if ( isset($_REQUEST['object']) and ( $_REQUEST['object'] == 'filter' ) ) {
       $_REQUEST['filter']['Background'] = empty($_REQUEST['filter']['Background']) ? 0 : 1;
       $_REQUEST['filter']['Concurrent'] = empty($_REQUEST['filter']['Concurrent']) ? 0 : 1;
       $changes = $filter->changes($_REQUEST['filter']);
-      ZM\Logger::Debug('Changes: ' . print_r($changes,true));
+      ZM\Debug('Changes: ' . print_r($changes, true));
 
-      if ( $_REQUEST['Id'] and ( $action == 'Save' ) ) {
-        if ( $filter->Background() )
+      if (count($changes)) {
+        if ($filter->Id() and ($action == 'Save') and $filter->Background()) {
           $filter->control('stop');
-        $filter->save($changes);
-      } else {
+        } else if ($action == 'execute') {
+          # If there are changes use a temp filter to do the execute
+          $filter->Name('_TempFilter'.time());
+          $filter->Id(null);
+        } else if ($action == 'SaveAs') {
+          $filter->Id(null);
+        }
+        if (!$filter->save($changes)) {
+          $error_message = $filter->get_last_error();
+          return;
+        }
+        // We update the request id so that the newly saved filter is auto-selected
+        $_REQUEST['Id'] = $filter->Id();
+      } # end if changes
 
-        if ( $action == 'execute' ) {
-          if ( count($changes) ) {
-            $filter->Name('_TempFilter'.time());
-            $filter->Id(null);
-          }
-        } else if ( $action == 'SaveAs' ) {
-					$filter->Id(null);
-				}
-        $filter->save($changes);
-
-				// We update the request id so that the newly saved filter is auto-selected
-				$_REQUEST['Id'] = $filter->Id();
-      }
-
-      if ( $action == 'execute' ) {
+      if ($action == 'execute') {
         $filter->execute();
-        if ( count($changes) )
+        if (count($changes)) {
           $filter->delete();
-
-        $view = 'events';
-      } else if ( $filter->Background() ) {
+					$filter->Id(null);
+        }
+      } else if ($filter->Background()) {
         $filter->control('start');
       }
+      global $redirect;
+      $redirect = '?view=filter'.$filter->querystring('filter', '&');
 
-    } else if ( $action == 'control' ) {
+    } else if ($action == 'control') {
       if ( $_REQUEST['command'] == 'start'
         or $_REQUEST['command'] == 'stop'
         or $_REQUEST['command'] == 'restart'
@@ -108,5 +108,4 @@ if ( isset($_REQUEST['object']) and ( $_REQUEST['object'] == 'filter' ) ) {
     } // end if save or execute
   } // end if canEdit(Events)
 } // end if object == filter
-
 ?>
