@@ -1,5 +1,4 @@
 <?php
-
 // Wrapper around setcookie that auto-sets samesite, and deals with older versions of php
 function zm_setcookie($cookie, $value, $options=array()) {
   if (!isset($options['expires'])) {
@@ -14,12 +13,12 @@ function zm_setcookie($cookie, $value, $options=array()) {
   } else {
     setcookie($cookie, $value, $options['expires'], '/; samesite=strict');
   }
+  ZM\Debug("Setting cookie for $cookie to $value");
 }
 
 // ZM session start function support timestamp management
 function zm_session_start() {
-
-  if ( ini_get('session.name') != 'ZMSESSID' ) {
+  if (ini_get('session.name') != 'ZMSESSID') {
     // Make sure use_strict_mode is enabled.
     // use_strict_mode is mandatory for security reasons.
     ini_set('session.use_strict_mode', 1);
@@ -67,13 +66,16 @@ function zm_session_regenerate_id() {
 
   // Set deleted timestamp. Session data must not be deleted immediately for reasons.
   $_SESSION['last_time'] = time();
-  // Finish session
   session_write_close();
 
   session_start();
+  
+  ZM\Debug("Regenerating session. Old id was " . session_id());
   session_regenerate_id();
+  ZM\Debug("Regenerating session. New id was " . session_id());
   unset($_SESSION['last_time']);
   $_SESSION['generated_at'] = time();
+  $_SESSION['remoteAddr'] = $_SERVER['REMOTE_ADDR']; // To help prevent session hijacking
 } // function zm_session_regenerate_id()
 
 function is_session_started() {
@@ -95,50 +97,61 @@ function zm_session_clear() {
   if ( ini_get('session.use_cookies') ) {
     $p = session_get_cookie_params();
     # Update the cookie to expire in the past.
-    setcookie(session_name(), '', time() - 31536000, $p['path'], $p['domain'], $p['secure'], $p['httponly']);
+    $p['expires'] = time() - 31536000;
+    unset($p['lifetime']); // Not valid for a cookie
+    zm_setcookie(session_name(), '', $p);
   }
   session_unset();
   session_destroy();
   session_write_close();
 } // function zm_session_clear()
 
-class Session {
+class ZMSessionHandler implements SessionHandlerInterface {
   private $db;
   public function __construct() {
     global $dbConn;
     $this->db = $dbConn;
 
     // Set handler to overide SESSION
+    /*
     session_set_save_handler(
       array($this, '_open'),
       array($this, '_close'),
       array($this, '_read'),
       array($this, '_write'),
       array($this, '_destroy'),
-      array($this, '_gc')
+      array($this, '_gc'),
+      array($this, '_create_sid'),
+      array($this, '_validate_sid')
     );
-
-    // Start the session
-    //zm_session_start();
+*/
   }
-  public function _open() {
+  public function open($path, $name) {
     return $this->db ? true : false;
   }
-  public function _close(){
+  public function close() {
     // The example code closed the db connection.. I don't think we care to.
     return true;
   }
-  public function _read($id){
+  #[\ReturnTypeWillChange]
+  public function read($id){
     $sth = $this->db->prepare('SELECT data FROM Sessions WHERE id = :id');
-    $sth->bindParam(':id', $id, PDO::PARAM_STR, 32);
+    if (!$sth->bindParam(':id', $id, PDO::PARAM_STR, 32)) {
+      ZM\Error('Failed to bind param');
+      if (!$sth->bindParam(':id', $id, PDO::PARAM_STR)) {
+        ZM\Error('Failed to bind param');
+      }
+    }
 
-    if ( $sth->execute() and ( $row = $sth->fetch(PDO::FETCH_ASSOC) ) ) {
-      return $row['data'];
+    if ($sth->execute()) {
+      if (($row = $sth->fetch(PDO::FETCH_ASSOC))) {
+        return $row['data'];
+      } 
     }
     // Return an empty string
     return '';
   }
-  public function _write($id, $data){
+  public function write($id, $data) {
     // Create time stamp
     $access = time();
 
@@ -150,12 +163,13 @@ class Session {
 
     return $sth->execute() ? true : false;
   }
-  public function _destroy($id) {
+  public function destroy($id) {
     $sth = $this->db->prepare('DELETE FROM Sessions WHERE Id = :id');
     $sth->bindParam(':id', $id, PDO::PARAM_STR, 32);
     return $sth->execute() ? true : false;
   }
-  public function _gc($max) {
+  #[\ReturnTypeWillChange]
+  public function gc($max) {
     // Calculate what is to be deemed old
     $now = time();
     $old = $now - $max;
@@ -164,7 +178,9 @@ class Session {
     $sth->bindParam(':old', $old, PDO::PARAM_INT);
     return $sth->execute() ? true : false;
   }
+  public function validateId($key) {return true;}
 } # end class Session
 
-$session = new Session;
+$session = new ZMSessionHandler;
+session_set_save_handler($session, true);
 ?>
