@@ -149,7 +149,6 @@ function MonitorStream(monitorData) {
       const newSrc = oldSrc.replace(/scale=\d+/i, 'scale='+newscale);
       if (newSrc != oldSrc) {
         this.streamCmdTimer = clearTimeout(this.streamCmdTimer);
-        this.statusCmdTimer = clearTimeout(this.statusCmdTimer);
         // We know that only the first zms will get the command because the
         // second can't open the commandQueue until the first exits
         // This is necessary because safari will never close the first image
@@ -160,7 +159,6 @@ function MonitorStream(monitorData) {
         console.log("Changing src to " + newSrc);
         img.src = '';
         img.src = newSrc;
-        this.statusCmdTimer = setTimeout(this.statusQuery.bind(this), statusRefreshTimeout);
       }
     }
   }; // setscale
@@ -189,7 +187,6 @@ function MonitorStream(monitorData) {
       stream.src = '';
       stream.src = src;
     }
-    this.statusCmdTimer = setTimeout(this.statusQuery.bind(this), delay);
     stream.onerror = this.img_onerror.bind(this);
     stream.onload = this.img_onload.bind(this);
   }; // this.start
@@ -233,10 +230,14 @@ function MonitorStream(monitorData) {
   };
 
   this.setup_onclick = function(func) {
-    this.onclick = func;
-    const el = this.getFrame();
-    if (!el) return;
-    el.addEventListener('click', this.onclick, false);
+    if (func) {
+      this.onclick = func;
+    }
+    if (this.onclick) {
+      const el = this.getFrame();
+      if (!el) return;
+      el.addEventListener('click', this.onclick, false);
+    }
   };
 
   this.disable_onclick = function() {
@@ -517,6 +518,7 @@ function MonitorStream(monitorData) {
       this.streamCmdParms.command = CMD_QUERY;
       this.streamCmdReq(this.streamCmdParms);
     }
+    this.streamCmdTimer = setTimeout(this.streamCmdQuery.bind(this), statusRefreshTimeout);
   };
 
   this.streamCommand = function(command) {
@@ -541,7 +543,10 @@ function MonitorStream(monitorData) {
 
     this.ajaxQueue = jQuery.ajaxQueue({
       url: this.url,
-      data: alarmCmdParms, dataType: "json"})
+      xhrFields: { withCredentials: true },
+      data: alarmCmdParms,
+      dataType: "json"
+    })
         .done(this.getStreamCmdResponse.bind(this))
         .fail(this.onFailure.bind(this));
   };
@@ -555,7 +560,12 @@ function MonitorStream(monitorData) {
     }
 
     this.streamCmdReq = function(streamCmdParms) {
-      this.ajaxQueue = jQuery.ajaxQueue({url: this.url, data: streamCmdParms, dataType: "json"})
+      this.ajaxQueue = jQuery.ajaxQueue({
+        url: this.url,
+        xhrFields: { withCredentials: true },
+        data: streamCmdParms,
+        dataType: "json"
+      })
           .done(this.getStreamCmdResponse.bind(this))
           .fail(this.onFailure.bind(this));
     };
