@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web function view file, $Date$, $Revision$
+// ZoneMinder web monitors view file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -39,12 +39,12 @@ foreach ( $storage_areas as $S ) {
 $focusWindow = true;
 
 xhtmlHeaders(__FILE__, translate('Function'));
+getBodyTopHTML();
+echo getNavBarHTML();
+
 ?>
-<body>
   <div id="page">
-    <div id="header">
-      <h2><?php echo translate('Function') ?></h2>
-    </div>
+    <h2 class="pt-2"><?php echo translate('Monitors') ?></h2>
     <div id="content">
 The following monitors will have these settings update when you click Save:<br/><br/>
       <?php echo implode('<br/>', array_map(function($m){return $m->Id().' ' .$m->Name();}, $monitors)); ?>
@@ -88,10 +88,9 @@ The following monitors will have these settings update when you click Save:<br/>
         </p>
         <div id="contentButtons">
           <button type="submit" value="Save"><?php echo translate('Save') ?></button>
-          <button type="button" data-on-click="closeWindow"><?php echo translate('Cancel') ?></button>
+          <button type="button" data-on-click="backWindow"><?php echo translate('Cancel') ?></button>
         </div>
       </form>
     </div>
   </div>
-</body>
-</html>
+<?php xhtmlFooter() ?>
